@@ -41,7 +41,7 @@ from atlasapi.whitelist import WhitelistEntry
 from atlasapi.maintenance_window import MaintenanceWindow, Weekdays
 from atlasapi.lib import AtlasLogNames, LogLine
 from requests import get
-from api_keys import ApiKey
+# from api_keys import ApiKey
 import gzip
 
 logger = logging.getLogger('Atlas')
@@ -321,9 +321,10 @@ class Atlas:
             """
             # Check new_cluster_size type:
             try:
-                assert isinstance(new_cluster_size,InstanceSizeName)
+                assert isinstance(new_cluster_size, InstanceSizeName)
             except AssertionError:
-                raise TypeError(f'new_cluster_size must be an instance of InstanceSizeName, not a {type(new_cluster_size)}')
+                raise TypeError(
+                    f'new_cluster_size must be an instance of InstanceSizeName, not a {type(new_cluster_size)}')
 
             # First check to see if this is a new size, and if the cluster exists
             try:
@@ -462,7 +463,8 @@ class Atlas:
 
             return return_val
 
-        def fill_host_list(self, for_cluster: Optional[str] = None) -> List[Host]:
+        def fill_host_list(self, for_cluster: Optional[str] = None) -> Union[
+            List[object], _SpecialForm[ListOfHosts, dict]]:
             """
             Fills the `self.hostname` property with the current hosts for the project/group.
 
@@ -697,6 +699,7 @@ class Atlas:
 
             Currently the log_file property (List) is usually with only one item.
             Args:
+                cluster_name (str): The human readable name of the cluster
                 log_name (AtlasLogNames): The type of log to be retrieved
                 date_from (datetime) : Start of log entries
                 date_to (datetime): End of log entries
@@ -1419,6 +1422,7 @@ class AtlasPagination:
             pageNum += 1
 
 
+# noinspection PyTypeChecker
 class ClustersGetAll(AtlasPagination):
     """Pagination for Clusters : Get All"""
 
@@ -1426,6 +1430,7 @@ class ClustersGetAll(AtlasPagination):
         super().__init__(atlas, atlas.Clusters.get_all_clusters, pageNum, itemsPerPage)
 
 
+# noinspection PyTypeChecker
 # noinspection PyProtectedMember
 class HostsGetAll(AtlasPagination):
     """Pagination for Processes : Get All"""
@@ -1435,12 +1440,14 @@ class HostsGetAll(AtlasPagination):
 
 
 # noinspection PyProtectedMember
+# noinspection PyTypeChecker
 class EventsGetForProject(AtlasPagination):
 
     def __init__(self, atlas: Atlas, pageNum: int, itemsPerPage: int):
         super().__init__(atlas, atlas.Events._get_all_project_events, pageNum, itemsPerPage)
 
 
+# noinspection PyTypeChecker
 class DatabaseUsersGetAll(AtlasPagination):
     """Pagination for Database User : Get All"""
 
@@ -1451,6 +1458,7 @@ class DatabaseUsersGetAll(AtlasPagination):
 class AlertsGetAll(AtlasPagination):
     """Pagination for Alerts : Get All"""
 
+    # noinspection PyTypeChecker
     def __init__(self, atlas, status, pageNum, itemsPerPage):
         super().__init__(atlas, self.fetch, pageNum, itemsPerPage)
         self.get_all_alerts = atlas.Alerts.get_all_alerts
@@ -1472,5 +1480,6 @@ class AlertsGetAll(AtlasPagination):
 class WhitelistGetAll(AtlasPagination):
     """Pagination for Database User : Get All"""
 
+    # noinspection PyTypeChecker
     def __init__(self, atlas, pageNum, itemsPerPage):
         super().__init__(atlas, atlas.Whitelist.get_all_whitelist_entries, pageNum, itemsPerPage)
